@@ -1,5 +1,5 @@
 # GERBLS version
-__version__ = "0.7.0"
+__version__ = "0.7.1"
 
 # Compiled Cython library
 from _gerbls import *
@@ -8,7 +8,5 @@ from _gerbls import *
 from .blsfunc import run_bls
 
 # Optional extras
-try:
-    from .clean import clean_savgol
-except ImportError:
-    pass
\ No newline at end of file
+from .clean import clean_savgol
+from .trmodel import LDModel
\ No newline at end of file
